var SwiperLeft = (function (exports, moment) {
  'use strict';

  moment = moment && moment.hasOwnProperty('default') ? moment['default'] : moment;

  //

  var dateValidator = function (value) { return /\d{4}-\d{2}-\d{2}/.test(value); };

  var script = {
    name: 'Xdate',
    props: {
      date: {
        type: String,
        default: function default$1 () {
          return moment().format('YYYY-MM-DD');
        },
        validator: dateValidator
      },
      loadDistance: { // 开始加载距离
        type: Number,
        default: 40
      },
      loadLen: { // 每次加载长度
        type: Number,
        default: 10
      },
      max: { // 显示的最大值
        type: String,
        validator: dateValidator
      },
      min: { // 显示的最小值
        type: String,
        validator: dateValidator
      },
      isDisable: { // 值是否可选
        type: Function,
        default: function () { return false; }
      }
    },
    data: function data () {
      return {
        dateList: [],
        selected: this.date
      }
    },
    created: function created () {
      this.initList();
    },
    mounted: function mounted () {
      this.activeToMid(); // 滚到中间，😘
    },
    methods: {
      initList: function initList () {
        var mDate = moment(this.date);
        this.dateList = [{
          id: mDate.format('YYYY-MM-DD'),
          ymdw: this.getYmdw(mDate)
        }];
        this.appendDate(this.loadLen);
        this.prependDate(this.loadLen);
      },
      getLastDateOfMonth: function getLastDateOfMonth (y, m) {
        // 下一个月第一天减一天就是这个月的最后一天
        var nextMonth = m == 12 ? 1 : m + 1;
        return moment((y + "-" + (this.prepad0(nextMonth, 2)) + "-01")).subtract(1, 'days').date();
      },
      prepad0: function prepad0 (target, len) {
        return ('000000' + target).slice(-len);
      },
      appendDate: function appendDate (num) {
        var ref$1;

        var lastDate = this.dateList[this.dateList.length - 1];
        var appendList = [];
        var lastDateOfMonth = this.getLastDateOfMonth(lastDate.ymdw.y, lastDate.ymdw.m);
        var i = 0;
        for (i = 0; i < num; i++) {
          // 第一个没有，拿lastDate来循环
          var prevDate = appendList[appendList.length - 1] || lastDate;
          // 不能大于设定值
          if (this.max && prevDate.id >= this.max) {
            break;
          }
          var ref = prevDate.ymdw;
          var y = ref.y;
          var m = ref.m;
          var d = ref.d;
          var w = ref.w;
          if (d === lastDateOfMonth) { // 最后一天需要重置天数
            if (m === 12) { // 12月的最后一天年份加1月份重置为1
              m = 1;
              y = y + 1;
            } else {
              m = m + 1;
            }
            d = 1;
            lastDateOfMonth = this.getLastDateOfMonth(y, m); // 月份变了需要修改最后一天
          } else {
            d = d + 1;
          }
          w = w === 6 ? 0 : w + 1;
          var item = {
            id: [y, this.prepad0(m, 2), this.prepad0(d, 2)].join('-'),
            ymdw: { y: y, m: m, d: d, w: w }
          };
          item.isDisable = this.isDisable(item);
          appendList.push(item);
        }
        // 怼进列表里面
        (ref$1 = this.dateList).push.apply(ref$1, appendList);
        return i;
      },
      prependDate: function prependDate (num) {
        var ref$1;

        var firstDate = this.dateList[0];
        var prependList = [];
        var i = 0;
        for (i = 0; i < num; i++) {
          var prevDate = prependList[0] || firstDate;
          // 不能小于设定值
          if (this.min && prevDate.id <= this.min) {
            break;
          }
          var ref = prevDate.ymdw;
          var y = ref.y;
          var m = ref.m;
          var d = ref.d;
          var w = ref.w;
          if (d === 1) {
            if (m === 1) { // 1月变成12月
              m = 12;
              y = y - 1;
            } else {
              m = m - 1;
            }
            d = this.getLastDateOfMonth(y, m); // 1号需要推到上一个月的最后一天
          } else {
            d = d - 1;
          }
          w = w === 0 ? 6 : w - 1;
          var item = {
            id: [y, this.prepad0(m, 2), this.prepad0(d, 2)].join('-'),
            ymdw: { y: y, m: m, d: d, w: w }
          };
          item.isDisable = this.isDisable(item);
          prependList.unshift(item);
        }
        (ref$1 = this.dateList).unshift.apply(ref$1, prependList);
        return i; // i是实际增加的个数
      },
      formatDate: function formatDate (mDate) {
        if (this.format) {
          return this.format(mDate.toDate());
        }
        return mDate.format('MM-DD');
      },
      getYmdw: function getYmdw (mDate) {
        return {
          y: mDate.year(),
          m: mDate.month() + 1,
          d: mDate.date(),
          w: mDate.day()
        };
      },
      // 滚动到中间位置
      activeToMid: function activeToMid (anim) {
        var this$1 = this;
        if ( anim === void 0 ) anim = false;

        var $xdate = this.$refs.xdate;
        var $active = $xdate.getElementsByClassName('active')[0];
        var dist = $active.offsetLeft + $active.offsetWidth / 2 - $xdate.clientWidth / 2;

        // 移动到中间时，如果需要加载新item，需要加载完成后再移动！
        if ($xdate.scrollWidth - dist - $xdate.clientWidth < this.loadDistance) {
          var newLen = this.appendDate(this.loadLen);
          if (newLen > 0) {
            this.$nextTick(function () { return this$1.activeToMid(anim); });
            return;
          }
        } else if (dist < this.loadDistance) {
          var newLen$1 = this.prependDate(this.loadLen);
          if (newLen$1 > 0) {
            this.$nextTick(function () {
              $xdate.scrollLeft = $active.offsetWidth * newLen$1 + $xdate.scrollLeft;
              this$1.activeToMid(anim);
            });
            return;
          }
        }

        if (anim) { // 点击后需要一个动画😝
          var duration = 200; // 持续时间300ms;
          var startStamp = new Date().getTime();
          var startPos = $xdate.scrollLeft;
          var loop = function () {
            window.requestAnimationFrame(function () {
              var current = new Date().getTime();
              var delta = current - startStamp;
              if (delta >= duration) {
                $xdate.scrollLeft = dist;
              } else {
                $xdate.scrollLeft = delta / duration * (dist - startPos) + startPos;
                loop();
              }
            });
          };
          loop();
        } else {
          $xdate.scrollLeft = dist;
        }
      },
      select: function select (item) {
        var this$1 = this;

        this.$emit('select', item);
        if (item.isDisable) { return; }
        this.selected = item.id;
        this.$nextTick(function () {
          this$1.activeToMid(true);
        });
      },
      scroll: function scroll (e) {
        var $xdate = e.target;
        var $item = $xdate.getElementsByClassName('xdate-item')[0];
        var loadDistance = this.loadDistance;
        if ($xdate.scrollLeft <= loadDistance) {
          var newLen = this.prependDate(this.loadLen);
          this.$nextTick(function () {
            $xdate.scrollLeft = $item.offsetWidth * newLen + $xdate.scrollLeft;
          });
        } else if ($xdate.scrollWidth - $xdate.scrollLeft - $xdate.clientWidth <= loadDistance) {
          this.appendDate(this.loadLen);
        }
      }
    }
  };

  function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier
  /* server only */
  , shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
      createInjectorSSR = createInjector;
      createInjector = shadowMode;
      shadowMode = false;
    } // Vue.extend constructor export interop.


    var options = typeof script === 'function' ? script.options : script; // render functions

    if (template && template.render) {
      options.render = template.render;
      options.staticRenderFns = template.staticRenderFns;
      options._compiled = true; // functional template

      if (isFunctionalTemplate) {
        options.functional = true;
      }
    } // scopedId


    if (scopeId) {
      options._scopeId = scopeId;
    }

    var hook;

    if (moduleIdentifier) {
      // server build
      hook = function hook(context) {
        // 2.3 injection
        context = context || // cached call
        this.$vnode && this.$vnode.ssrContext || // stateful
        this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext; // functional
        // 2.2 with runInNewContext: true

        if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
          context = __VUE_SSR_CONTEXT__;
        } // inject component styles


        if (style) {
          style.call(this, createInjectorSSR(context));
        } // register component module identifier for async chunk inference


        if (context && context._registeredComponents) {
          context._registeredComponents.add(moduleIdentifier);
        }
      }; // used by ssr in case component is cached and beforeCreate
      // never gets called


      options._ssrRegister = hook;
    } else if (style) {
      hook = shadowMode ? function () {
        style.call(this, createInjectorShadow(this.$root.$options.shadowRoot));
      } : function (context) {
        style.call(this, createInjector(context));
      };
    }

    if (hook) {
      if (options.functional) {
        // register for functional component in vue file
        var originalRender = options.render;

        options.render = function renderWithStyleInjection(h, context) {
          hook.call(context);
          return originalRender(h, context);
        };
      } else {
        // inject component registration as beforeCreate hook
        var existing = options.beforeCreate;
        options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
      }
    }

    return script;
  }

  var normalizeComponent_1 = normalizeComponent;

  var isOldIE = typeof navigator !== 'undefined' && /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());
  function createInjector(context) {
    return function (id, style) {
      return addStyle(id, style);
    };
  }
  var HEAD = document.head || document.getElementsByTagName('head')[0];
  var styles = {};

  function addStyle(id, css) {
    var group = isOldIE ? css.media || 'default' : id;
    var style = styles[group] || (styles[group] = {
      ids: new Set(),
      styles: []
    });

    if (!style.ids.has(id)) {
      style.ids.add(id);
      var code = css.source;

      if (css.map) {
        // https://developer.chrome.com/devtools/docs/javascript-debugging
        // this makes source maps inside style tags work properly in Chrome
        code += '\n/*# sourceURL=' + css.map.sources[0] + ' */'; // http://stackoverflow.com/a/26603875

        code += '\n/*# sourceMappingURL=data:application/json;base64,' + btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) + ' */';
      }

      if (!style.element) {
        style.element = document.createElement('style');
        style.element.type = 'text/css';
        if (css.media) { style.element.setAttribute('media', css.media); }
        HEAD.appendChild(style.element);
      }

      if ('styleSheet' in style.element) {
        style.styles.push(code);
        style.element.styleSheet.cssText = style.styles.filter(Boolean).join('\n');
      } else {
        var index = style.ids.size - 1;
        var textNode = document.createTextNode(code);
        var nodes = style.element.childNodes;
        if (nodes[index]) { style.element.removeChild(nodes[index]); }
        if (nodes.length) { style.element.insertBefore(textNode, nodes[index]); }else { style.element.appendChild(textNode); }
      }
    }
  }

  var browser = createInjector;

  /* script */
  var __vue_script__ = script;

  /* template */
  var __vue_render__ = function() {
    var _vm = this;
    var _h = _vm.$createElement;
    var _c = _vm._self._c || _h;
    return _c("div", { staticClass: "xdate" }, [
      _c(
        "div",
        { ref: "xdate", staticClass: "xdate-scroll", on: { scroll: _vm.scroll } },
        [
          _c(
            "div",
            { staticClass: "xdate-list" },
            _vm._l(_vm.dateList, function(item) {
              return _c(
                "div",
                {
                  key: item.id,
                  staticClass: "xdate-item",
                  class: {
                    active: _vm.selected === item.id,
                    disable: item.isDisable
                  },
                  on: {
                    click: function($event) {
                      return _vm.select(item)
                    }
                  }
                },
                [
                  _vm._t(
                    "default",
                    [
                      _c("p", [
                        _vm._v(
                          _vm._s(_vm.prepad0(item.ymdw.m, 2)) +
                            "-" +
                            _vm._s(_vm.prepad0(item.ymdw.d, 2))
                        )
                      ])
                    ],
                    { item: item }
                  )
                ],
                2
              )
            }),
            0
          )
        ]
      )
    ])
  };
  var __vue_staticRenderFns__ = [];
  __vue_render__._withStripped = true;

    /* style */
    var __vue_inject_styles__ = function (inject) {
      if (!inject) { return }
      inject("data-v-5736a58a_0", { source: ".xdate {\n  width: 100vw;\n}\n.xdate * {\n    box-sizing: border-box;\n}\n.xdate .xdate-scroll {\n    overflow: scroll;\n    width: 100%;\n}\n.xdate .xdate-list {\n    white-space: nowrap;\n}\n.xdate .xdate-item {\n    display: inline-block;\n    width: 20vw;\n    text-align: center;\n    min-height: 40px;\n    line-height: 20px;\n    padding: 10px 0;\n}\n.xdate .active {\n    background-color: #1890ff;\n    color: #fff;\n}\n.xdate .disable {\n    color: #999;\n}\n\n/*# sourceMappingURL=xdate.vue.map */", map: {"version":3,"sources":["/Users/a/Documents/vue-xdate/src/xdate.vue","xdate.vue"],"names":[],"mappings":"AAiPA;EAIA,YAAA;AAAA;AAJA;IAEA,sBAAA;AAAA;AAFA;IAMA,gBAAA;IACA,WACA;AAAA;AARA;IAUA,mBAAA;AAAA;AAVA;IAaA,qBAAA;IACA,WAAA;IACA,kBAAA;IACA,gBAAA;IACA,iBAAA;IACA,eAAA;AAAA;AAlBA;IAqBA,yBAAA;IACA,WAAA;AAAA;AAtBA;IAyBA,WAAA;AAAA;;ACpPA,oCAAoC","file":"xdate.vue","sourcesContent":["<template>\n  <div class=\"xdate\">\n    <div class=\"xdate-scroll\" ref=\"xdate\" @scroll=\"scroll\">\n      <div class=\"xdate-list\">\n        <div v-for=\"item in dateList\"\n          :key=\"item.id\"\n          class=\"xdate-item\"\n          :class=\"{\n            active: selected === item.id,\n            disable: item.isDisable\n          }\"\n          @click=\"select(item)\"\n        >\n          <slot :item=\"item\">\n            <p>{{prepad0(item.ymdw.m, 2)}}-{{prepad0(item.ymdw.d, 2)}}</p>\n          </slot>\n        </div>\n      </div>\n    </div>\n  </div>\n</template>\n<script>\nimport moment from 'moment';\n\nconst dateValidator = value => /\\d{4}-\\d{2}-\\d{2}/.test(value);\n\nexport default {\n  name: 'Xdate',\n  props: {\n    date: {\n      type: String,\n      default () {\n        return moment().format('YYYY-MM-DD');\n      },\n      validator: dateValidator\n    },\n    loadDistance: { // 开始加载距离\n      type: Number,\n      default: 40\n    },\n    loadLen: { // 每次加载长度\n      type: Number,\n      default: 10\n    },\n    max: { // 显示的最大值\n      type: String,\n      validator: dateValidator\n    },\n    min: { // 显示的最小值\n      type: String,\n      validator: dateValidator\n    },\n    isDisable: { // 值是否可选\n      type: Function,\n      default: () => false\n    }\n  },\n  data () {\n    return {\n      dateList: [],\n      selected: this.date\n    }\n  },\n  created () {\n    this.initList();\n  },\n  mounted () {\n    this.activeToMid(); // 滚到中间，😘\n  },\n  methods: {\n    initList () {\n      const mDate = moment(this.date);\n      this.dateList = [{\n        id: mDate.format('YYYY-MM-DD'),\n        ymdw: this.getYmdw(mDate)\n      }];\n      this.appendDate(this.loadLen);\n      this.prependDate(this.loadLen);\n    },\n    getLastDateOfMonth (y, m) {\n      // 下一个月第一天减一天就是这个月的最后一天\n      const nextMonth = m == 12 ? 1 : m + 1;\n      return moment(`${y}-${this.prepad0(nextMonth, 2)}-01`).subtract(1, 'days').date();\n    },\n    prepad0 (target, len) {\n      return ('000000' + target).slice(-len);\n    },\n    appendDate (num) {\n      const lastDate = this.dateList[this.dateList.length - 1];\n      const appendList = [];\n      let lastDateOfMonth = this.getLastDateOfMonth(lastDate.ymdw.y, lastDate.ymdw.m);\n      let i = 0;\n      for (i = 0; i < num; i++) {\n        // 第一个没有，拿lastDate来循环\n        const prevDate = appendList[appendList.length - 1] || lastDate;\n        // 不能大于设定值\n        if (this.max && prevDate.id >= this.max) {\n          break;\n        }\n        let { y, m, d, w } = prevDate.ymdw;\n        if (d === lastDateOfMonth) { // 最后一天需要重置天数\n          if (m === 12) { // 12月的最后一天年份加1月份重置为1\n            m = 1;\n            y = y + 1;\n          } else {\n            m = m + 1;\n          }\n          d = 1;\n          lastDateOfMonth = this.getLastDateOfMonth(y, m); // 月份变了需要修改最后一天\n        } else {\n          d = d + 1;\n        }\n        w = w === 6 ? 0 : w + 1;\n        const item = {\n          id: [y, this.prepad0(m, 2), this.prepad0(d, 2)].join('-'),\n          ymdw: { y, m, d, w }\n        };\n        item.isDisable = this.isDisable(item);\n        appendList.push(item);\n      }\n      // 怼进列表里面\n      this.dateList.push(...appendList);\n      return i;\n    },\n    prependDate (num) {\n      const firstDate = this.dateList[0];\n      const prependList = [];\n      let i = 0;\n      for (i = 0; i < num; i++) {\n        const prevDate = prependList[0] || firstDate;\n        // 不能小于设定值\n        if (this.min && prevDate.id <= this.min) {\n          break;\n        }\n        let { y, m, d, w } = prevDate.ymdw;\n        if (d === 1) {\n          if (m === 1) { // 1月变成12月\n            m = 12;\n            y = y - 1;\n          } else {\n            m = m - 1;\n          }\n          d = this.getLastDateOfMonth(y, m); // 1号需要推到上一个月的最后一天\n        } else {\n          d = d - 1;\n        }\n        w = w === 0 ? 6 : w - 1;\n        const item = {\n          id: [y, this.prepad0(m, 2), this.prepad0(d, 2)].join('-'),\n          ymdw: { y, m, d, w }\n        };\n        item.isDisable = this.isDisable(item);\n        prependList.unshift(item);\n      }\n      this.dateList.unshift(...prependList);\n      return i; // i是实际增加的个数\n    },\n    formatDate (mDate) {\n      if (this.format) {\n        return this.format(mDate.toDate());\n      }\n      return mDate.format('MM-DD');\n    },\n    getYmdw (mDate) {\n      return {\n        y: mDate.year(),\n        m: mDate.month() + 1,\n        d: mDate.date(),\n        w: mDate.day()\n      };\n    },\n    // 滚动到中间位置\n    activeToMid (anim = false) {\n      const $xdate = this.$refs.xdate;\n      const $active = $xdate.getElementsByClassName('active')[0];\n      const dist = $active.offsetLeft + $active.offsetWidth / 2 - $xdate.clientWidth / 2;\n\n      // 移动到中间时，如果需要加载新item，需要加载完成后再移动！\n      if ($xdate.scrollWidth - dist - $xdate.clientWidth < this.loadDistance) {\n        const newLen = this.appendDate(this.loadLen);\n        if (newLen > 0) {\n          this.$nextTick(() => this.activeToMid(anim));\n          return;\n        }\n      } else if (dist < this.loadDistance) {\n        const newLen = this.prependDate(this.loadLen);\n        if (newLen > 0) {\n          this.$nextTick(() => {\n            $xdate.scrollLeft = $active.offsetWidth * newLen + $xdate.scrollLeft;\n            this.activeToMid(anim);\n          });\n          return;\n        }\n      }\n\n      if (anim) { // 点击后需要一个动画😝\n        const duration = 200; // 持续时间300ms;\n        const startStamp = new Date().getTime();\n        const startPos = $xdate.scrollLeft;\n        const loop = () => {\n          window.requestAnimationFrame(() => {\n            const current = new Date().getTime();\n            const delta = current - startStamp;\n            if (delta >= duration) {\n              $xdate.scrollLeft = dist;\n            } else {\n              $xdate.scrollLeft = delta / duration * (dist - startPos) + startPos;\n              loop();\n            }\n          });\n        }\n        loop();\n      } else {\n        $xdate.scrollLeft = dist;\n      }\n    },\n    select (item) {\n      this.$emit('select', item);\n      if (item.isDisable) return;\n      this.selected = item.id;\n      this.$nextTick(() => {\n        this.activeToMid(true);\n      });\n    },\n    scroll (e) {\n      const $xdate = e.target;\n      const $item = $xdate.getElementsByClassName('xdate-item')[0]\n      const loadDistance = this.loadDistance;\n      if ($xdate.scrollLeft <= loadDistance) {\n        const newLen = this.prependDate(this.loadLen);\n        this.$nextTick(() => {\n          $xdate.scrollLeft = $item.offsetWidth * newLen + $xdate.scrollLeft;\n        });\n      } else if ($xdate.scrollWidth - $xdate.scrollLeft - $xdate.clientWidth <= loadDistance) {\n        this.appendDate(this.loadLen);\n      }\n    }\n  }\n}\n</script>\n<style lang=\"scss\">\n.xdate {\n  * {\n    box-sizing: border-box;\n  }\n  width: 100vw;\n  .xdate-scroll {\n    overflow: scroll;\n    width: 100%\n  }\n  .xdate-list {\n    white-space: nowrap;\n  }\n  .xdate-item {\n    display: inline-block;\n    width: 20vw;\n    text-align: center;\n    min-height: 40px;\n    line-height: 20px;\n    padding: 10px 0;\n  }\n  .active {\n    background-color: #1890ff;\n    color: #fff;\n  }\n  .disable {\n    color: #999;\n  }\n}\n</style>\n",".xdate {\n  width: 100vw; }\n  .xdate * {\n    box-sizing: border-box; }\n  .xdate .xdate-scroll {\n    overflow: scroll;\n    width: 100%; }\n  .xdate .xdate-list {\n    white-space: nowrap; }\n  .xdate .xdate-item {\n    display: inline-block;\n    width: 20vw;\n    text-align: center;\n    min-height: 40px;\n    line-height: 20px;\n    padding: 10px 0; }\n  .xdate .active {\n    background-color: #1890ff;\n    color: #fff; }\n  .xdate .disable {\n    color: #999; }\n\n/*# sourceMappingURL=xdate.vue.map */"]}, media: undefined });

    };
    /* scoped */
    var __vue_scope_id__ = undefined;
    /* module identifier */
    var __vue_module_identifier__ = undefined;
    /* functional template */
    var __vue_is_functional_template__ = false;
    /* style inject SSR */
    

    
    var Xdate = normalizeComponent_1(
      { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
      __vue_inject_styles__,
      __vue_script__,
      __vue_scope_id__,
      __vue_is_functional_template__,
      __vue_module_identifier__,
      browser,
      undefined
    );

  Xdate.install = function () {
    Vue.component(Xdate.name, Xdate);
  };

  exports.default = Xdate;

  return exports;

}({}, moment));
